package com.example.target;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

public class Results extends Activity {
	
	// Target variables
	private double targX = 0.0;
	private double targY = 0.0;
	private double targSpeed = 0.0;
	private double targHeading = 0.0;
	
	// Projectile variables
	private double projX = 0.0;
	private double projY = 0.0;
	private double projHeight = 0.0;
	private double projSpeed = 0.0;
	private boolean projShape = true;
	private double projSize = 0.0;
	
	// Calculation variables
	private double radian;
	private double time;
	private double distance;
	private double deltaX;
	private double deltaY;
	private double distFrom;
	final double PI = 3.1415;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
		Bundle extras = getIntent().getExtras();
		if (extras != null) {
			targX = extras.getDouble("targX");
			targY = extras.getDouble("targY");
			targSpeed = extras.getDouble("targSpeed");
			targHeading = extras.getDouble("targHeading");
			
			projX = extras.getDouble("projX");
			projY = extras.getDouble("projY");
			projHeight = extras.getDouble("projHeight");
			projSpeed = extras.getDouble("projSpeed");
			projSize = extras.getDouble("projSize");
			projShape = extras.getBoolean("projShape");
			
		}
        setContentView(R.layout.output);
        
        

        // All checks correct, run calculations
    	calculate();
    	fillOutput();
    	
    	// Create return button
    	final Button returnButton = (Button) findViewById(R.id.ButtonResult);
    	returnButton.setOnClickListener(new OnClickListener()
    	{
			//@Override
			public void onClick(View arg0) {
    			finish();
			}
    	});
    	
    }
    
    private void fillOutput() {
   	
    	String output = "";
    	
		final TextView targPos = (TextView) findViewById(R.id.TextOutTargPos);
		final TextView targSpd = (TextView) findViewById(R.id.TextOutTargSpeed);
		final TextView targHd = (TextView) findViewById(R.id.TextOutTargHead);
		
		final TextView projPos = (TextView) findViewById(R.id.TextOutProjPos);
		final TextView projSd = (TextView) findViewById(R.id.TextOutProjSpeed);
		final TextView projShp = (TextView) findViewById(R.id.TextOutProjShape);
		
		final TextView finalPos = (TextView) findViewById(R.id.TextOutPos);
		final TextView finalTime = (TextView) findViewById(R.id.TextOutTime);
		final TextView result = (TextView) findViewById(R.id.TextOutResult);
		
		try {
			targPos.setText(getString(R.string.out_targetPos) + " " + Double.toString(targX) + ", " + Double.toString(targY));
			targSpd.setText(getString(R.string.out_targetSpeed) + " " + Double.toString(targSpeed));
			targHd.setText(getString(R.string.out_targetHead) + " " +Double.toString(targHeading));
		
			projPos.setText(getString(R.string.out_projPos) + " " + Double.toString(projX) + ", " + Double.toString(projY));
			projSd.setText(getString(R.string.out_projSpeed) + " " + Double.toString(projSpeed));
			
			if (projShape)
				output = getString(R.string.out_projShape) + " " +
						 getString(R.string.proj_square) + " " +
				         getString(R.string.out_projSizeSq) + " " +
				         Double.toString(projSize);
			else
				output = getString(R.string.out_projShape) + " " +
						 getString(R.string.proj_circle) + " " +
				         getString(R.string.out_projSizeCr) + " " + 
						 Double.toString(projSize);
			
			projShp.setText(output);
			
			finalTime.setText(getString(R.string.out_time) + " " + Double.toString(time));
			finalPos.setText(getString(R.string.out_pos) + " " + Double.toString(deltaX) + ", " + Double.toString(deltaY));
		
			if(projShape)
			{  // Projectile is a cube
				double x_max = projX + projSize;
				double x_min = projX - projSize;
				double y_max = projY + projSize;
				double y_min = projY - projSize;
				if (deltaX <= x_max && deltaX >= x_min && deltaY <= y_max && deltaY >= y_min)
				   result.setText(R.string.out_hit);
				else
					result.setText(R.string.out_miss);
			}
			else // Projectile is a cylinder
			{
			    if (projSize >= distFrom)
			    	result.setText(R.string.out_hit);
			   	else
			   		result.setText(R.string.out_miss);
			}
		}
		catch(Exception e)
		{
			Toast.makeText(Results.this, "Error setting text " + e.toString(), Toast.LENGTH_SHORT).show();
		}
		return;
	}

	private void calculate()
    {
    	radian = degreesRadian(targHeading);
    	time = howLong(projHeight, projSpeed);
    	distance = distToTarg(time, targSpeed);
    	deltaX = changeX(distance, radian, targX);
    	deltaY = changeY(distance, radian, targY);
    	distFrom = distTargProj(deltaX, deltaY, projX, projY);
    }


	private double distTargProj(double deltX, double deltY,
			double prjX, double prjY) {
		return Math.sqrt(Math.pow((prjX - deltX), 2) + Math.pow((prjY - deltY), 2));

	}

	private double changeX(double dist, double rad, double trgX) {

		double correction = dist * Math.sin(rad);
		return  correction + trgX ; 
		
	}
	
	private double changeY(double dist, double rad, double trgY) {
		double correction = dist * Math.cos(rad);
		return  correction + trgY ; 
	}

	private double distToTarg(double tm, double trgSpeed) {

		return tm * trgSpeed;
	}

	private double howLong(double prjHeight, double prjSpeed) {

		return prjHeight/prjSpeed;
	}

	private double degreesRadian(double trgHeading) {
		// TODO Auto-generated method stub
		return PI/180.0 * trgHeading;
	}
};


