package com.example.target;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.TextView;
import android.widget.Toast;
import java.lang.Math;


public class Target extends Activity {
    /** Called when the activity is first created. */
	// Target variables
	private double targX = 0.0;
	private double targY = 0.0;
	private double targSpeed = 0.0;
	private double targHeading = 0.0;
	
	// Projectile variables
	private double projX = 0.0;
	private double projY = 0.0;
	private double projHeight = 0.0;
	private double projSpeed = 0.0;
	private boolean projShape = true;
	private double projSize = 0.0;
	
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.input);
        
        // Define all EditText fields
        final EditText editTargX = (EditText) findViewById(R.id.EditTextTargX);
        final EditText editTargY = (EditText) findViewById(R.id.EditTextTargY);
        final EditText editTargSpeed = (EditText) findViewById(R.id.EditTextTargSpeed);
        final EditText editTargHead = (EditText) findViewById(R.id.EditTextTargHead);
        
        final EditText editProjX = (EditText) findViewById(R.id.EditTextProjX);
        final EditText editProjY = (EditText) findViewById(R.id.EditTextProjY);
        final EditText editProjSpeed = (EditText) findViewById(R.id.EditTextProjSpeed);
        final EditText editProjHeight = (EditText) findViewById(R.id.EditTextProjHeight);
        final EditText editProjSize = (EditText) findViewById(R.id.EditTextProjSize);
        
        // Define the radio buttons
        final RadioButton radioSquare = (RadioButton) findViewById(R.id.ProjSquare);
        final RadioButton radioCircle = (RadioButton) findViewById(R.id.ProjCircle);
        
        // Set projShape to the correct value
        final OnClickListener radio_listener = new OnClickListener() {
            public void onClick(View v) {
                // Perform action on clicks
                RadioButton rb = (RadioButton) v;
                if (rb.getText() == getString(R.string.proj_square))
                	projShape = true;
                else
                	projShape = false;
            }
        };
        
        radioSquare.setOnClickListener(radio_listener);
        radioCircle.setOnClickListener(radio_listener);

        
        // Define the calculation button
        final Button buttonCalc = (Button) findViewById(R.id.ButtonCalc);
//        
        final OnClickListener input;
        input = new OnClickListener()
        {
            public void onClick(View v) {
                // Perform action on clicks
            	// Check for empty fields
            	if(editTargX.getText().toString() == "" ||
            	   editTargY.getText().toString() == "" ||
            	   editTargSpeed.getText().toString() == "" ||
            	   editTargHead.getText().toString() == "" ||
            	   editProjX.getText().toString() == "" ||
            	   editProjY.getText().toString() == "" ||
            	   editProjSpeed.getText().toString() == "" ||
            	   editProjHeight.getText().toString() == "" ||
            	   editProjSize.getText().toString() == "")
            	{
            		Toast.makeText(Target.this, R.string.err_empty, Toast.LENGTH_SHORT).show();
            		return;
            	}
            	
            	// Set variables to input, check for nonnumerical input
            	try {
            	targX = Double.parseDouble(editTargX.getText().toString());
            	targY = Double.parseDouble(editTargY.getText().toString());
            	targSpeed = Double.parseDouble(editTargSpeed.getText().toString());
            	targHeading = Double.parseDouble(editTargHead.getText().toString());
            	projX = Double.parseDouble(editProjX.getText().toString());
            	projY = Double.parseDouble(editProjY.getText().toString());
            	projSpeed = Double.parseDouble(editProjSpeed.getText().toString());
            	projHeight = Double.parseDouble(editProjHeight.getText().toString());
            	projSize = Double.parseDouble(editProjSize.getText().toString());
            	}
            	catch (NumberFormatException nfe)
            	{
            		Toast.makeText(Target.this, R.string.err_notnum, Toast.LENGTH_SHORT).show();
            		return;
            	}
            	
            	// Check for negative values
            	if (targSpeed < 0 || projSpeed < 0)
            	{
            		Toast.makeText(Target.this, R.string.err_negspeed, Toast.LENGTH_SHORT).show();
            		return;
            	}
            	if (projHeight < 0)
            	{
            		Toast.makeText(Target.this, R.string.err_negheight, Toast.LENGTH_SHORT).show();
            		return;
            	}	
            	if (projSize < 0)
            	{
            		Toast.makeText(Target.this, R.string.err_negsize, Toast.LENGTH_SHORT).show();
            		return;
            	}	
            	
            	// Check to see if heading is in the correct range
            	if (targHeading < 0 || targHeading > 360)
            	{
            		Toast.makeText(Target.this, R.string.err_heading, Toast.LENGTH_SHORT).show();
            		return;            		
            	} 
            	
            	// Output - call the Results activity, send it the necessary data

                Intent i = new Intent(Target.this, Results.class);
                i.putExtra("targX", targX);
                i.putExtra("targY", targY);
                i.putExtra("targSpeed", targSpeed);
                i.putExtra("targHeading", targHeading);
                
                i.putExtra("projX", projX);
                i.putExtra("projY", projY);
                i.putExtra("projSpeed", projSpeed);
                i.putExtra("projHeight", projHeight);
                i.putExtra("projSize", projSize);
            	i.putExtra("projShape", projShape);
                
                startActivityForResult(i, 0);
            	
            }
        
        };

        buttonCalc.setOnClickListener(input);
    }
}